@@ -521,9 +521,13 @@ CPO <- rep(NA, N.all)
 LMPL <- sum(log(CPO), na.rm=TRUE)   
     
     
-## Create the Fitted values
+## Create the fitted values and residuals
 fitted.values <- apply(samples.fitted, 2, median)
-residuals <- as.numeric(Y) - fitted.values
+response.residuals <- as.numeric(Y) - fitted.values
+pearson.residuals <- response.residuals /sqrt(nu2.median)
+deviance.residuals <- sign(response.residuals) * sqrt((Y-fitted.values)^2/nu2.median)
+residuals <- data.frame(response=response.residuals, pearson=pearson.residuals, deviance=deviance.residuals)
+
     
     
 #### transform the parameters back to the origianl covariate scale.
@@ -599,8 +603,10 @@ summary.results[ , 4:7] <- round(summary.results[ , 4:7], 1)
     
     
 ## Compile and return the results
-modelfit <- c(DIC, p.d, WAIC, p.w, LMPL)
-names(modelfit) <- c("DIC", "p.d", "WAIC", "p.w", "LMPL")
+loglike <- (-0.5 * deviance.fitted)
+modelfit <- c(DIC, p.d, WAIC, p.w, LMPL, loglike)
+names(modelfit) <- c("DIC", "p.d", "WAIC", "p.w", "LMPL", "loglikelihood")
+
 if(fix.rho.S & fix.rho.T)
 {
     samples.rhoext <- NA
@@ -623,7 +629,7 @@ if(n.miss==0) samples.Y = NA
 samples <- list(beta=mcmc(samples.beta.orig), phi=mcmc(samples.phi),  rho=mcmc(samples.rhoext), tau2=mcmc(samples.tau2), nu2=mcmc(samples.nu2), fitted=mcmc(samples.fitted), Y=mcmc(samples.Y))
 model.string <- c("Likelihood model - Gaussian (identity link function)", "\nLatent structure model - Autoregressive CAR model\n")
 results <- list(summary.results=summary.results, samples=samples, fitted.values=fitted.values, residuals=residuals, modelfit=modelfit, accept=accept.final, localised.structure=NULL, formula=formula, model=model.string,  X=X)
-class(results) <- "carbayesST"
+class(results) <- "CARBayesST"
     if(verbose)
     {
         b<-proc.time()
