@@ -496,9 +496,13 @@ poisson.CARadaptive <- function(formula, data = NULL, W, burnin, n.sample, thin
   LMPL <- sum(log(CPO))    
   
   
-  ## Create the Fitted values
-  fitted.values      <- apply(samples.fit, 2, median)
-  residuals          <- as.numeric(y) - fitted.values
+  ## Create the fitted values and residuals
+  fitted.values <- apply(samples.fit, 2, median)
+  response.residuals <- as.numeric(y) - fitted.values
+  pearson.residuals <- response.residuals /sqrt(fitted.values)
+  deviance.residuals <- sign(response.residuals) * sqrt(2 * (y * log(y/fitted.values) + fitted.values - y))
+  residuals <- data.frame(response=response.residuals, pearson=pearson.residuals, deviance=deviance.residuals)
+  
   
   #### transform the parameters back to the origianl covariate scale.
   samples.beta.orig <- samples.beta
@@ -560,8 +564,9 @@ poisson.CARadaptive <- function(formula, data = NULL, W, burnin, n.sample, thin
   Wmn[locs[ ,c(2,1)]] <- bdryMN  
   
   ## Compile and return the results
-  modelfit <- c(DIC, p.d, WAIC, p.w, LMPL)
-  names(modelfit) <- c("DIC", "p.d", "WAIC", "p.w", "LMPL")
+  loglike <- (-0.5 * deviance.fitted)
+  modelfit <- c(DIC, p.d, WAIC, p.w, LMPL, loglike)
+  names(modelfit) <- c("DIC", "p.d", "WAIC", "p.w", "LMPL", "loglikelihood")
   model.string    <- c("Likelihood model - Poisson (log link function)", 
                        "\nLatent structure model - Adaptive autoregressive CAR model\n")
   samples.tau2all <- cbind(samples.tau2, samples.vtau2)
@@ -582,7 +587,7 @@ poisson.CARadaptive <- function(formula, data = NULL, W, burnin, n.sample, thin
   localised.structure <- list(Wmedian = Wmn, W99 = W99)
   results <- list(summary.results=summary.results, samples=samples, fitted.values=fitted.values, residuals=residuals, modelfit=modelfit, accept=accept.final, localised.structure=localised.structure, formula=formula, model=model.string,  X=X)
   
-  class(results) <- "carbayesST"
+  class(results) <- "CARBayesST"
   if(verbose)
   {
     b<-proc.time()
