@@ -806,9 +806,13 @@ CPO <- rep(NA, N.all)
 LMPL <- sum(log(CPO), na.rm=TRUE)  
        
   
-## Create the Fitted values
+## Create the fitted values and residuals
 fitted.values <- apply(samples.fitted, 2, median)
-residuals <- as.numeric(Y) - fitted.values
+response.residuals <- as.numeric(Y) - fitted.values
+pearson.residuals <- response.residuals /sqrt(fitted.values)
+deviance.residuals <- sign(response.residuals) * sqrt(2 * (Y * log(Y/fitted.values) + fitted.values - Y))
+residuals <- data.frame(response=response.residuals, pearson=pearson.residuals, deviance=deviance.residuals)
+
   
   
 #### transform the parameters back to the origianl covariate scale.
@@ -913,8 +917,10 @@ summary.results[ , 4:7] <- round(summary.results[ , 4:7], 1)
 
 
 ## Compile and return the results
-modelfit <- c(DIC, p.d, WAIC, p.w, LMPL)
-names(modelfit) <- c("DIC", "p.d", "WAIC", "p.w", "LMPL")
+loglike <- (-0.5 * deviance.fitted)
+modelfit <- c(DIC, p.d, WAIC, p.w, LMPL, loglike)
+names(modelfit) <- c("DIC", "p.d", "WAIC", "p.w", "LMPL", "loglikelihood")
+
 
 if(fix.rho.S & fix.rho.T)
 {
@@ -949,7 +955,7 @@ if(interaction)
 
 samples <- list(beta=mcmc(samples.beta.orig), phi=mcmc(samples.phi),  delta=mcmc(samples.delta), gamma=mcmc(samples.gamma), tau2=mcmc(samples.tau2), rho=mcmc(samples.rhoext), fitted=mcmc(samples.fitted), Y=mcmc(samples.Y))        
 results <- list(summary.results=summary.results, samples=samples, fitted.values=fitted.values, residuals=residuals, modelfit=modelfit, accept=accept.final, localised.structure=NULL, formula=formula, model=model.string,  X=X)
-class(results) <- "carbayesST"
+class(results) <- "CARBayesST"
      if(verbose)
      {
      b<-proc.time()
