@@ -713,9 +713,13 @@ for(j in 1:N.all)
 LMPL <- sum(log(CPO), na.rm=TRUE)  
     
     
-## Create the Fitted values
+## Create the fitted values and residuals
 fitted.values <- apply(samples.fitted, 2, median)
-residuals <- as.numeric(Y) - fitted.values
+response.residuals <- as.numeric(Y) - fitted.values
+pearson.residuals <- response.residuals /sqrt(fitted.values)
+deviance.residuals <- sign(response.residuals) * sqrt(2 * (Y * log(Y/fitted.values) + fitted.values - Y))
+residuals <- data.frame(response=response.residuals, pearson=pearson.residuals, deviance=deviance.residuals)
+
     
     
 #### transform the parameters back to the origianl covariate scale.
@@ -789,8 +793,10 @@ summary.results[ , 4:7] <- round(summary.results[ , 4:7], 1)
     
     
 ## Compile and return the results
-modelfit <- c(DIC, p.d, WAIC, p.w, LMPL)
-names(modelfit) <- c("DIC", "p.d", "WAIC", "p.w", "LMPL")
+loglike <- (-0.5 * deviance.fitted)
+modelfit <- c(DIC, p.d, WAIC, p.w, LMPL, loglike)
+names(modelfit) <- c("DIC", "p.d", "WAIC", "p.w", "LMPL", "loglikelihood")
+
 
 if(fix.rho.int & fix.rho.slo)
 {
@@ -814,8 +820,8 @@ if(n.miss==0) samples.Y = NA
 
 samples <- list(beta=mcmc(samples.beta.orig), alpha=mcmc(samples.alpha), phi=mcmc(samples.phi),  delta=mcmc(samples.delta), tau2=mcmc(samples.tau2), rho=mcmc(samples.rhoext), fitted=mcmc(samples.fitted), Y=mcmc(samples.Y))        
 model.string <- c("Likelihood model - Poisson (log link function)", "\nLatent structure model - Spatially autocorrelated linear time trends\n")
-results <- list(summary.results=summary.results, samples=samples, fitted.values=fitted.values, residuals=residuals, modelfit=modelfit, accept=accept.final, localised.structure=NULL, formula=formula, model=model.string,  X=X)
-class(results) <- "carbayesST"
+results <- list(summary.results=summary.results, samples=samples, fitted.values=fitted.values, residuals=residuals,  modelfit=modelfit, accept=accept.final, localised.structure=NULL, formula=formula, model=model.string,  X=X)
+class(results) <- "CARBayesST"
     if(verbose)
     {
         b<-proc.time()
